/*+		T D T 

 * Module name:
     Tdt

 * Function:
     Definitions of items from the tdt namespace, tdt::TdtFitsClass

 * Description:
     This module provides the implementation of items in the tdt namespace,
     TdtFitsClass as declared in tdt.hh.

     See document ASD82 (DRTF documentation) for details on the code used 
     below.

 * Language:
      C++

 * Support: {author}, AAO

 *-

* "@(#) $Id$"

 * History:
     {dd-mmm-yyyy} - {initials} - Original version

 *  Copyright (c) Macquarie University, {year}.
    Not to be used for commercial purposes without permission.
    No warranty of any form unless subject to a specific agreement.

 */
/*
 * RCS id
 */
static const char *rcsId="@(#) $Id$";
static void *use_rcsId = (0 ? (void *)(&use_rcsId) : (void *) &rcsId);

#include "tdt.hh"
#include "tdt_err.h"

/*
 * Constructor.  Not a great deal to do here.
 */
tdt::TdtFitsClass::TdtFitsClass(tdt::Task *theTask) : 
    drtf::FitsInterface(theTask),
    _parSys(theTask->TaskPtr()),
    _theTask(theTask)
{

}

/*
 * From Setup, we add any Fixed FITS keywords and link any parameters to 
 * keywords.  This is invoked during the initialisation of the overall system,
 * after this task has been initialised/reset.
 */
void tdt::TdtFitsClass::Setup() 
{
    /*
     * Task version details.  The keyword names will need to
     * be reworked to ensure they are less then 8 characters.
     */
    AddKey("TDTVER", _parSys.GetString("ENQ_VER_NUM"),
           "TDT DRAMA Task Build version");
    AddKey("TDTDAT", _parSys.GetString("ENQ_VER_DATE"), 
           "TDT Task Build date");

    /*
     * Add other fixed keywords using the above style.
     */

    /*
     * Link parameter values to keywords as required.  Here we are
     * linking the parameter INT_PARAM to the keyword INTKW.  The comment
     * for the keyword is specified and the last argument indicates
     * the value is known at the start of an exposure (as against the END
     * of the exposure).
     */
    LinkKey("INTKW",    "INT_PARAM",   "Comment for INT_PARAM", START);

}
/*
 * Add keyword values at the start of an exposure.
 *
 * This is invoked just before a science exposure starts and you
 * add any keywords from your task that are known at the point.
 */
void tdt::TdtFitsClass::Start(long int /*run_id*/)
{
    /*
     * A couple of examples of how to do this.
     */
    AddKey("HASTART", "12:00:01", "HA at start of exposure");
    AddKey("ZDSTART", 23.3, "ZD at start of exposre");

}
/*
 * Add keyword values at the end of an exposure.
 *
 * This is invoked just before a science exposure starts and you
 * add any keywords from your task that are known at the point.
 */
void tdt::TdtFitsClass::Finish(long int /*run_id*/)
{
    /*
     * A couple of examples of how to do this.
     */
    AddKey("HAEND", "12:55:01", "HA at end of exposure");
    AddKey("ZDEND", 25.3, "ZD at end of exposure");


}
